==> traveltimepy-3.3.0b1-py3-none-any.whl: tests/postcodes_test.py <==
from datetime import datetime

from traveltimepy import Coordinates, PublicTransport


def test_departures(sdk):
    results = sdk.postcodes(
        coordinates=[Coordinates(lat=51.507609, lng=-0.128315)],
        departure_time=datetime.now(),
        transportation=PublicTransport(),
    )
    assert len(results) > 0


def test_arrivals(sdk):
    results = sdk.postcodes(
        coordinates=[Coordinates(lat=51.507609, lng=-0.128315)],
        arrival_time=datetime.now(),
        transportation=PublicTransport(),
    )
    assert len(results) > 0


def test_districts_departure(sdk):
    results = sdk.postcode_districts(
        coordinates=[Coordinates(lat=51.507609, lng=-0.128315)],
        departure_time=datetime.now(),
        transportation=PublicTransport(),
    )
    assert len(results) > 0


def test_districts_arrival(sdk):
    results = sdk.postcode_districts(
        coordinates=[Coordinates(lat=51.507609, lng=-0.128315)],
        arrival_time=datetime.now(),
        transportation=PublicTransport(),
    )
    assert len(results) > 0


def test_sectors_departure(sdk):
    results = sdk.postcode_sectors(
        coordinates=[Coordinates(lat=51.507609, lng=-0.128315)],
        departure_time=datetime.now(),
        transportation=PublicTransport(),
    )
    assert len(results) > 0


def test_sectors_arrival(sdk):
    results = sdk.postcode_sectors(
        coordinates=[Coordinates(lat=51.507609, lng=-0.128315)],
        arrival_time=datetime.now(),
        transportation=PublicTransport(),
    )
    assert len(results) > 0

==> traveltimepy-3.6.1-py3-none-any.whl: tests/postcodes_test.py <==
import pytest
from datetime import datetime

from traveltimepy import Coordinates, PublicTransport


@pytest.mark.asyncio
async def test_departures(sdk):
    results = await sdk.postcodes_async(
        coordinates=[Coordinates(lat=51.507609, lng=-0.128315)],
        departure_time=datetime.now(),
        transportation=PublicTransport(),
    )
    assert len(results) > 0


@pytest.mark.asyncio
async def test_arrivals(sdk):
    results = await sdk.postcodes_async(
        coordinates=[Coordinates(lat=51.507609, lng=-0.128315)],
        arrival_time=datetime.now(),
        transportation=PublicTransport(),
    )
    assert len(results) > 0


@pytest.mark.asyncio
async def test_districts_departure(sdk):
    results = await sdk.postcodes_districts_async(
        coordinates=[Coordinates(lat=51.507609, lng=-0.128315)],
        departure_time=datetime.now(),
        transportation=PublicTransport(),
    )
    assert len(results) > 0


@pytest.mark.asyncio
async def test_districts_arrival(sdk):
    results = await sdk.postcodes_districts_async(
        coordinates=[Coordinates(lat=51.507609, lng=-0.128315)],
        arrival_time=datetime.now(),
        transportation=PublicTransport(),
    )
    assert len(results) > 0


@pytest.mark.asyncio
async def test_sectors_departure(sdk):
    results = await sdk.postcodes_sectors_async(
        coordinates=[Coordinates(lat=51.507609, lng=-0.128315)],
        departure_time=datetime.now(),
        transportation=PublicTransport(),
    )
    assert len(results) > 0


@pytest.mark.asyncio
async def test_sectors_arrival(sdk):
    results = await sdk.postcodes_sectors_async(
        coordinates=[Coordinates(lat=51.507609, lng=-0.128315)],
        arrival_time=datetime.now(),
        transportation=PublicTransport(),
    )
    assert len(results) > 0
